@@ -318,39 +318,50 @@ sub slurp {
 }
 
 sub save_file {
-    my ($filename, $new ) = @_;
+    my ($filename, $new) = @_;
     my $old = slurp( $filename );
-    if( $new ne $old ) {
-        print "Saving new version of $filename\n";
+    if ( $new ne $old ) {
+        warn "Saving new version of $filename";
         open my $fh, '>:raw', $filename
-            or die "Couldn't write new version of '$filename': $!";
+          or die "Couldn't write new version of '$filename': $!";
         print $fh $new;
-    };
-};
+    }
+}
 
 my $xs_code = generate_glew_xs( @ARGV );
 save_file( 'auto-xs.inc', $xs_code );
 
 # Now rewrite OpenGL::Modern.pm if we need to:
-if( ! @ARGV) {
-    my $module = 'lib/OpenGL/Modern.pm';
-    my $glFunctions = sprintf "our \@glFunctions = qw(\n    %s\n);", join "\n    ", @exported_functions;
+if ( !@ARGV ) {
+    my $glFunctions = join "\n      ", @exported_functions;
 
     my %glGroups = map {
-        $_ => [ map { $_->{name} } @{$features{$_}} ],
+        $_ => [ map { $_->{name} } @{ $features{$_} } ],
     } sort keys %features;
     use Data::Dumper;
     $Data::Dumper::Sortkeys = 1;
     my $gltags = Dumper \%glGroups;
     $gltags =~ s!\$VAR1 = \{!!;
-    $gltags =~ s!\s+};\r?$!!;
+    $gltags =~ s!\s+};$!!;
 
-    my $new = slurp( $module );
-    $new =~ s!\bour \@glFunctions = qw\(.*?\);!$glFunctions!sm;
-    # our %EXPORT_TAGS_GL = (
-    # );
-    # # end of EXPORT_TAGS_GL
-    $new =~ s!(our \%EXPORT_TAGS_GL = \().+(\);\s+# end of EXPORT_TAGS_GL)\r?$!$1$gltags$2!sm;
+    my $new = <<"END";
+package OpenGL::Modern::NameLists::Modern;
 
-    save_file( $module, $new);
-};
+# ATTENTION: This file is automatically generated by utils/generate-XS.pl!
+#            Manual changes will be lost.
+
+sub gl_functions {
+    qw(
+      $glFunctions
+    );
+}
+
+sub EXPORT_TAGS_GL {
+    ($gltags    );
+}
+
+1;
+END
+
+    save_file( "lib/OpenGL/Modern/NameLists/Modern.pm", $new );
+}
